Internet In A Box
=================

Project Homepage: http://internet-in-a-box.org


Abstract
--------

The Internet-in-a-Box is a small, inexpensive device which provides essential
Internet resources without any Internet connection.  It provides a local copy
of half a terabyte of the world's Free information.

An Internet-in-a-Box provides:

- *Wikipedia*: Complete Wikipedia in a dozen different languages
- *Maps*: Zoomable world-wide maps down to street level
- *E-books*: Over 35 thousand e-books in a variety of languages
- *Software*: Huge library of Open Source Software, including installable Ubuntu Linux OS with all software package repositories.  Includes full source code for study or modification.
- *Video*: Hundreds of hours of instructional videos
- *Chat*: Simple instant messaging across the community

The project founder is Braddock Gaskill at braddock@braddock.com

Installation
------------

See INSTALL.txt


----
